@@ -6,14 +6,14 @@ import sys
 
 def parser(help=False):
   
-  parser = argparse.ArgumentParser(description=gd.logo())
-  # Dump Gtihub account\'s all repos at once
+  parser = argparse.ArgumentParser(description='Dump all repos of a github account at once.')
+
   
   parser.add_argument('-u', '--username', dest='username',
-                      help='Username of the github account')
+                      help='sername of the github account')
 
   parser.add_argument('-l', '--location', dest='location',
-                      help='Location to save dumped repos')
+                      help='location to save dumped repos')
 
   def help_msg():
     parser.print_help(sys.stderr)
